@@ -21,22 +21,24 @@
 # CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 import re
+from typing import Optional, Tuple
 
 import dns
+import threading
 from dns.exception import DNSException
 
 from . import bitcoin
 from . import dnssec
-from .util import export_meta, import_meta, to_string
+from .util import read_json_file, write_json_file, to_string
 from .logging import Logger
-
+from .util import trigger_callback
 
 class Contacts(dict, Logger):
 
-    def __init__(self, storage):
+    def __init__(self, db):
         Logger.__init__(self)
-        self.storage = storage
-        d = self.storage.get('contacts', {})
+        self.db = db
+        d = self.db.get('contacts', {})
         try:
             self.update(d)
         except:
@@ -49,17 +51,16 @@ class Contacts(dict, Logger):
                 self[n] = ('address', k)
 
     def save(self):
-        self.storage.put('contacts', dict(self))
+        self.db.put('contacts', dict(self))
 
     def import_file(self, path):
-        import_meta(path, self._validate, self.load_meta)
-
-    def load_meta(self, data):
+        data = read_json_file(path)
+        data = self._validate(data)
         self.update(data)
         self.save()
 
-    def export_file(self, filename):
-        export_meta(self, filename)
+    def export_file(self, path):
+        write_json_file(path, self)
 
     def __setitem__(self, key, value):
         dict.__setitem__(self, key, value)
@@ -95,7 +96,19 @@ class Contacts(dict, Logger):
             }
         raise Exception("Invalid Bitcoin address or alias", k)
 
-    def resolve_openalias(self, url):
+    def fetch_openalias(self, config):
+        self.alias_info = None
+        alias = config.get('alias')
+        if alias:
+            alias = str(alias)
+            def f():
+                self.alias_info = self.resolve_openalias(alias)
+                trigger_callback('alias_received')
+            t = threading.Thread(target=f)
+            t.daemon = True
+            t.start()
+
+    def resolve_openalias(self, url: str) -> Optional[Tuple[str, str, bool]]:
         # support email-style addresses, per the OA standard
         url = url.replace('@', '.')
         try:
