@@ -143,7 +143,7 @@ class Ledger_Client(HardwareClientBase):
                          fingerprint=fingerprint_bytes,
                          child_number=childnum_bytes).to_xpub()
 
-    def has_detached_pin_support(self, client):
+    def has_detached_pin_support(self, client: 'btchip'):
         try:
             client.getVerifyPinRemainingAttempts()
             return True
@@ -152,7 +152,7 @@ class Ledger_Client(HardwareClientBase):
                 return False
             raise e
 
-    def is_pin_validated(self, client):
+    def is_pin_validated(self, client: 'btchip'):
         try:
             # Invalid SET OPERATION MODE to verify the PIN status
             client.dongle.exchange(bytearray([0xe0, 0x26, 0x00, 0x00, 0x01, 0xAB]))
@@ -246,10 +246,6 @@ class Ledger_KeyStore(Hardware_KeyStore):
 
     def __init__(self, d):
         Hardware_KeyStore.__init__(self, d)
-        # Errors and other user interaction is done through the wallet's
-        # handler.  The handler is per-window and preserved across
-        # device reconnects
-        self.force_watching_only = False
         self.signing = False
         self.cfg = d.get('cfg', {'mode': 0})
 
@@ -258,20 +254,17 @@ class Ledger_KeyStore(Hardware_KeyStore):
         obj['cfg'] = self.cfg
         return obj
 
-    def get_client(self):
-        return self.plugin.get_client(self).dongleObject
+    def get_client_dongle_object(self, *, client: Optional['Ledger_Client'] = None) -> 'btchip':
+        if client is None:
+            client = self.get_client()
+        return client.dongleObject
 
-    def get_client_electrum(self) -> Optional[Ledger_Client]:
-        return self.plugin.get_client(self)
-
-    def give_error(self, message, clear_client = False):
+    def give_error(self, message):
         _logger.info(message)
         if not self.signing:
             self.handler.show_error(message)
         else:
             self.signing = False
-        if clear_client:
-            self.client = None
         raise UserFacingException(message)
 
     def set_and_unset_signing(func):
@@ -294,8 +287,8 @@ class Ledger_KeyStore(Hardware_KeyStore):
         message = message.encode('utf8')
         message_hash = hashlib.sha256(message).hexdigest().upper()
         # prompt for the PIN before displaying the dialog if necessary
-        client_ledger = self.get_client()
-        client_electrum = self.get_client_electrum()
+        client_electrum = self.get_client()
+        client_ledger = self.get_client_dongle_object(client=client_electrum)
         address_path = self.get_derivation_prefix()[2:] + "/%d/%d"%sequence
         self.handler.show_message("Signing message ...\r\nMessage hash: "+message_hash)
         try:
@@ -310,18 +303,20 @@ class Ledger_KeyStore(Hardware_KeyStore):
             signature = client_ledger.signMessageSign(pin)
         except BTChipException as e:
             if e.sw == 0x6a80:
-                self.give_error("Unfortunately, this message cannot be signed by the Ledger wallet. Only alphanumerical messages shorter than 140 characters are supported. Please remove any extra characters (tab, carriage return) and retry.")
+                self.give_error("Unfortunately, this message cannot be signed by the Ledger wallet. "
+                                "Only alphanumerical messages shorter than 140 characters are supported. "
+                                "Please remove any extra characters (tab, carriage return) and retry.")
             elif e.sw == 0x6985:  # cancelled by user
                 return b''
             elif e.sw == 0x6982:
                 raise  # pin lock. decorator will catch it
             else:
-                self.give_error(e, True)
+                self.give_error(e)
         except UserWarning:
             self.handler.show_error(_('Cancelled by user'))
             return b''
         except Exception as e:
-            self.give_error(e, True)
+            self.give_error(e)
         finally:
             self.handler.finished()
         # Parse the ASN.1 signature
@@ -356,9 +351,10 @@ class Ledger_KeyStore(Hardware_KeyStore):
         p2shTransaction = False
         segwitTransaction = False
         pin = ""
-        client_ledger = self.get_client() # prompt for the PIN before displaying the dialog if necessary
-        client_electrum = self.get_client_electrum()
+        # prompt for the PIN before displaying the dialog if necessary
+        client_electrum = self.get_client()
         assert client_electrum
+        client_ledger = self.get_client_dongle_object(client=client_electrum)
 
         # Fetch inputs of the transaction to sign
         for txin in tx.inputs():
@@ -545,10 +541,10 @@ class Ledger_KeyStore(Hardware_KeyStore):
                 raise  # pin lock. decorator will catch it
             else:
                 self.logger.exception('')
-                self.give_error(e, True)
+                self.give_error(e)
         except BaseException as e:
             self.logger.exception('')
-            self.give_error(e, True)
+            self.give_error(e)
         finally:
             self.handler.finished()
 
@@ -556,13 +552,13 @@ class Ledger_KeyStore(Hardware_KeyStore):
     @test_pin_unlocked
     @set_and_unset_signing
     def show_address(self, sequence, txin_type):
-        client = self.get_client()
+        client_ledger = self.get_client_dongle_object()
         address_path = self.get_derivation_prefix()[2:] + "/%d/%d"%sequence
         self.handler.show_message(_("Showing address ..."))
         segwit = is_segwit_script_type(txin_type)
         segwitNative = txin_type == 'p2wpkh'
         try:
-            client.getWalletPublicKey(address_path, showOnScreen=True, segwit=segwit, segwitNative=segwitNative)
+            client_ledger.getWalletPublicKey(address_path, showOnScreen=True, segwit=segwit, segwitNative=segwitNative)
         except BTChipException as e:
             if e.sw == 0x6985:  # cancelled by user
                 pass
@@ -585,7 +581,6 @@ class Ledger_KeyStore(Hardware_KeyStore):
 class LedgerPlugin(HW_PluginBase):
     keystore_class = Ledger_KeyStore
     minimum_library = (0, 1, 32)
-    client = None
     DEVICE_IDS = [
                    (0x2581, 0x1807), # HW.1 legacy btchip
                    (0x2581, 0x2b7c), # HW.1 transitional production
@@ -691,9 +686,6 @@ class LedgerPlugin(HW_PluginBase):
 
     @runs_in_hwd_thread
     def create_client(self, device, handler):
-        if handler:
-            self.handler = handler
-
         client = self.get_btchip_device(device)
         if client is not None:
             client = Ledger_Client(client, product_key=device.product_key, plugin=self)
